==> haskell-tasty-hunit-0.10.1-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.1
visibility:           public
id:                   tasty-hunit-0.10.1-4olJEdoQaAQ1sPVsKcqoD
key:                  tasty-hunit-0.10.1-4olJEdoQaAQ1sPVsKcqoD
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  a90d8e9a8acf1b7ee4a091f3c54e8ea8
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hunit-0.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hunit-0.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hunit-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.1-4olJEdoQaAQ1sPVsKcqoD
depends:
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    tasty-1.4.3-HK16IWl2qZuAE1kQP7GLN3

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.1-125-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hunit
version:              0.10.1
visibility:           public
id:                   tasty-hunit-0.10.1-8HEgC7xeFLr4lIM7OklMXL
key:                  tasty-hunit-0.10.1-8HEgC7xeFLr4lIM7OklMXL
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  21c9c0069f07d46230dc62ff8a76e3eb
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hunit-0.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hunit-0.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hunit-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.1-8HEgC7xeFLr4lIM7OklMXL
depends:
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    tasty-1.4.3-9dAIvYL9PVBHOxSIGECWdI

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
